StepData class

Constructors

StepData(int steps, double calories, double speedKmh, String status, double cadence, DateTime time)

Properties

cadence double
final
calories double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speedKmh double
final
status String
final
steps int
final
time DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited