StepCounter class
Constructors
- StepCounter()
-
factory
Properties
- cadence → double
-
no setter
- caloriesBurned → double
-
no setter
- currentStep → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- monthlySteps → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stepStream
→ Stream<
StepData> -
no setter
- stepThreshold → double
-
final
- strideLengthMeters → double
-
no setter
- todaySteps → int
-
no setter
- userHeightMeters ↔ double
-
getter/setter pair
- userWeightKg ↔ double
-
getter/setter pair
- walkingSpeedKmh → double
-
no setter
- weeklySteps → int
-
no setter
Methods
-
init(
{required double weightKg, required double heightMeters}) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → Future< void> -
start(
) → Future< void> -
stop(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
updateUserHeight(
double heightMeters) → void -
updateUserWeight(
double weightKg) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited